@@ -31,9 +31,7 @@ sub new {
 sub read {
     # Mbox reader, works as an iterator.
     # @return   [String] Contents of mbox
-    my $self = shift;
-    return undef unless -T $self->{'handle'};
-
+    my $self       = shift; return "" unless -T $self->{'handle'};
     my $readhandle = $self->{'handle'};
     my $readbuffer = '';
     eval {
@@ -120,7 +118,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2016,2018-2021,2024 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2016,2018-2021,2024,2025 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
