@@ -13,7 +13,7 @@ sub match {
     #                           1: Matched
     # @since v4.22.0
     my $class = shift;
-    my $argv1 = shift // return undef;
+    my $argv1 = shift // return 0;
 
     state $index = [
         'an illegal attachment on your message',
@@ -55,7 +55,7 @@ sub true {
     #                                   0: is not policyviolation
     # @since v4.22.0
     # @see http://www.ietf.org/rfc/rfc2822.txt
-    return undef;
+    return 0;
 }
 
 1;
@@ -112,7 +112,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2017-2024 azumakuniyuki, All rights reserved.
+Copyright (C) 2017-2025 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
