@@ -12,7 +12,7 @@ sub match {
     #                           1: Matched
     # @since v4.0.0
     my $class = shift;
-    my $argv1 = shift // return undef;
+    my $argv1 = shift // return 0;
 
     state $index = [
         ' is currently suspended',
@@ -51,13 +51,11 @@ sub true {
     # @since v4.0.0
     # @see http://www.ietf.org/rfc/rfc2822.txt
     my $class = shift;
-    my $argvs = shift // return undef;
-    return undef unless $argvs->{'deliverystatus'};
+    my $argvs = shift // return 0;
 
     return 1 if $argvs->{'reason'} eq 'suspend';
     return 1 if length $argvs->{'replycode'} && $argvs->{'replycode'} == 525;
-    return 1 if __PACKAGE__->match(lc $argvs->{'diagnosticcode'});
-    return 0
+    return __PACKAGE__->match(lc $argvs->{'diagnosticcode'});
 }
 
 1;
@@ -105,7 +103,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2021,2023,2024 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2021,2023-2025 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
