@@ -2,6 +2,7 @@ package Sisimai::Reason::VirusDetected;
 use v5.26;
 use strict;
 use warnings;
+use Sisimai::SMTP::Command;
 
 sub text  { 'virusdetected' }
 sub description { 'Email rejected due to a virus scanner on a destination host' }
@@ -12,7 +13,7 @@ sub match {
     #                           1: Matched
     # @since v4.22.0
     my $class = shift;
-    my $argv1 = shift // return undef;
+    my $argv1 = shift // return 0;
 
     state $index = [
         'it has a potentially executable attachment',
@@ -34,17 +35,14 @@ sub true {
     # @since v4.22.0
     # @see http://www.ietf.org/rfc/rfc2822.txt
     my $class = shift;
-    my $argvs = shift // return undef;
+    my $argvs = shift // return 0;
 
-    # The value of "reason" isn't "virusdetected" when the value of "smtpcommand" is an SMTP com-
-    # mand to be sent before the SMTP DATA command because all the MTAs read the headers and the
-    # entire message body after the DATA command.
+    # The value of "reason" isn't "virusdetected" when the value of "command" is an SMTP command to
+    # be sent before the SMTP DATA command because all the MTAs read the headers and the entire
+    # message body after the DATA command.
     return 1 if $argvs->{'reason'} eq 'virusdetected';
-    return 0 if $argvs->{'smtpcommand'} eq 'CONN' || $argvs->{'smtpcommand'} eq 'HELO'
-             || $argvs->{'smtpcommand'} eq 'HELO' || $argvs->{'smtpcommand'} eq 'MAIL'
-             || $argvs->{'smtpcommand'} eq 'RCPT';
-    return 1 if __PACKAGE__->match(lc $argvs->{'diagnosticcode'});
-    return 0;
+    return 0 if grep { $argvs->{'command'} eq $_ } Sisimai::SMTP::Command->ExceptDATA->@*;
+    return __PACKAGE__->match(lc $argvs->{'diagnosticcode'});
 }
 
 1;
@@ -101,7 +99,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2017-2021,2023,2024 azumakuniyuki, All rights reserved.
+Copyright (C) 2017-2021,2023-2025 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
