@@ -14,7 +14,7 @@ sub find {
     # @see      https://technet.microsoft.com/en-us/library/bb232118
     # @since v4.17.2
     my $class = shift;
-    my $argvs = shift // return undef;
+    my $argvs = shift // return "";
     return '' unless $argvs->{'deliverystatus'};
     return '' unless Sisimai::SMTP::Status->test($argvs->{'deliverystatus'});
 
@@ -32,6 +32,13 @@ sub find {
             # - Access denied, sending domain [$SenderDomain] does not pass DMARC verification
             # - The sender's domain in the 5322.From address doesn't pass DMARC.
             ['5.7.509', 0, 0, 'does not pass dmarc verification'],
+
+            # - 550 5.7.515 Access denied, sending domain EXAMPLE.JP doesn't meet the required
+            #   authentication level. The sender's domain in the 5322.From address doesn't meet
+            #   the authentication requirements defined for the sender. To learn how to fix this
+            #   see: https://go.microsoft.com/fwlink/p/?linkid=2319303
+            #   Spf= Fail , Dkim= Pass , DMARC= Pass ...
+            ["5.7.515", 0, 0, "doesn't meet the required authentication level"],
         ],
         'badreputation' => [
             # Undocumented error messages ---------------------------------------------------------
@@ -193,10 +200,10 @@ sub find {
         ],
         'failedstarttls' => [
             # Exchange Online ---------------------------------------------------------------------
-            # - MX hosts of <domain> failed MTA-STS validation The destination MX host is not the
+            # - MX hosts of <domain> failed MTA-STS validation The destination MX host is not the
             #   expected host per the domain's STS policy
-            ["4.4.8", 0, 0, " failed mta-sts validation"],
-            ["5.4.8", 0, 0, " failed mta-sts validation"],
+            ["4.4.8", 0, 0, " failed mta-sts validation"],
+            ["5.4.8", 0, 0, " failed mta-sts validation"],
 
             # - DNSSEC checks have passed, yet upon connection, destination mail server doesn't re-
             #   spond to the STARTTLS command. The destination server responds to the STARTTLS com-
@@ -207,12 +214,12 @@ sub find {
             ['4.4.317', 0, 0, 'starttls is required to send mail'],
             ['5.4.317', 0, 0, 'starttls is required to send mail'],
 
-            # - Remote certificate failed MTA-STS validation. Reason: <validityStatus> The destina-
+            # - Remote certificate failed MTA-STS validation. Reason: <validityStatus> The destina-
             #   tion mail server's certificate must chain to a trusted root Certificate Authority
             #   and the Common Name or Subject Alternative Name must contain an entry for the host
             #   name in the STS policy.
-            ["4.7.5", 0, 0, "remote certificate failed mta-sts validation"],
-            ["5.7.5", 0, 0, "remote certificate failed mta-sts validation"],
+            ["4.7.5", 0, 0, "remote certificate failed mta-sts validation"],
+            ["5.7.5", 0, 0, "remote certificate failed mta-sts validation"],
 
             # - DNSSEC checks have passed, yet upon establishing the connection the destination
             #   mail server provides a certificate that is expired.
@@ -623,11 +630,16 @@ sub find {
             ['5.2.14', 0, 0, 'misconfigured forwarding address'],
 
             # Undocumented error messages ---------------------------------------------------------
-            ['4.4.3',  0, 0, 'temporary server error. please try again later attr18'],
-            ['4.7.0',  0, 0, 'temporary server error. please try again later. prx4 nexthop:'],
-            ['4.4.24', 0, 0, 'message failed to be replicated: insufficient system resource:'],
-            ['4.4.25', 0, 0, 'message failed to be replicated: no healthy secondary server available to accept replica at this time.'],
-            ['4.4.28', 0, 0, 'message failed to be replicated: the operation was canceled'],
+            # - 451 4.4.22 Message failed to be replicated: no healthy peers found ... (in reply to end of DATA command)
+            # - 451 4.4.23 Message failed to be replicated: No healthy secondary server available
+            #   to accept replica at this time. ... (in reply to end of DATA command)
+            # - 451 4.4.28 Message failed to be replicated:
+            #   Microsoft.Exchange.Transport.Net.Http.TransportHttpException(session Id: -1) ...(in reply to end of DATA command)
+            # - 451 4.4.28 Message failed to be replicated:
+            #   System.Net.Http.HttpRequestException(session Id: ****) ... (in reply to end of DATA command)
+            ["4.4.",  22, 28, "message failed to be replicated:"],
+            ["4.4.3",  0,  0, "temporary server error. please try again later attr18"],
+            ["4.7.0",  0,  0, "temporary server error. please try again later. prx4 nexthop:"],
 
             # 550 5.4.318 Message expired, connection reset (SuspiciousRemoteServerError)
             # 450 4.4.318 Connection was closed abruptly (SuspiciousRemoteServerError)
