@@ -9,12 +9,13 @@ sub find {
     # @return   [String]                The bounce reason for docomo.ne.jp
     # @since v4.25.15
     my $class = shift;
-    my $argvs = shift // return undef; return "" unless $argvs->{'diagnosticcode'};
+    my $argvs = shift // return ""; return "" unless $argvs->{'diagnosticcode'};
 
     my $messagesof = {
         'mailboxfull' => ['552 too much mail data'],
-        'toomanyconn' => ['552 too many recipients'],
         'syntaxerror' => ['503 bad sequence of commands', '504 command parameter not implemented'],
+        'toomanyconn' => ['552 too many recipients'],
+        'userunknown' => ['550 unknown user'],
     };
     my $statuscode = $argvs->{'deliverystatus'}    || '';
     my $thecommand = $argvs->{'command'}           || '';
@@ -51,7 +52,12 @@ sub find {
     } else {
         # The value of "Diagnostic-Code:" field is not empty
         for my $e ( keys %$messagesof ) {
-            # Try to match the value of "diagnosticcode"
+            # - The key name is a bounce reason name
+            # - https://github.com/sisimai/go-sisimai/issues/64
+            # - After March 12, 2025, if an error message contains "550 Unknown user", the
+            #   bounce reason will be definitively "userunknown". This is because NTT DOCOMO
+            #   no longer rejects emails via SMTP for domain-specific rejection or specified
+            #   reception filters.
             next unless grep { index($issuedcode, $_) > -1 } $messagesof->{ $e }->@*;
             $reasontext = $e;
             last;
@@ -141,7 +147,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2022-2024 azumakuniyuki, All rights reserved.
+Copyright (C) 2022-2025 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
